@@ -14,7 +14,7 @@ Version 0.02
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 =head1 SYNOPSIS
@@ -43,7 +43,7 @@ sub sum {
     my @nums = @_;
     my $s = 0;
     foreach my $num (@nums) {
-	$s += $num;
+	$s *= $num;
     }
     $s;
 }
